<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined( 'ABSPATH' ) || exit;

$wc_thememove_page_layout_private = get_post_meta( wc_get_page_id( 'shop' ), "thememove_page_layout_private", true );
$wc_thememove_bread_crumb_enable  = get_post_meta( wc_get_page_id( 'shop' ), "thememove_bread_crumb_enable", true );
$wc_thememove_heading_image       = get_post_meta( wc_get_page_id( 'shop' ), "thememove_heading_image", true );
$wc_thememove_sticky_header       = get_post_meta( wc_get_page_id( 'shop' ), "thememove_sticky_header", true );
$wc_thememove_uncover_enable      = get_post_meta( wc_get_page_id( 'shop' ), "thememove_uncover_enable", true );
$wc_thememove_uncover_enable      = get_post_meta( wc_get_page_id( 'shop' ), "thememove_uncover_enable", true );
$wc_thememove_header_top          = get_post_meta( wc_get_page_id( 'shop' ), "thememove_header_top", true );
if ( $wc_thememove_page_layout_private != 'default' ) {
	$layout = $wc_thememove_page_layout_private;
} else {
	$layout = get_theme_mod( 'site_layout', site_layout );
}
get_header( 'shop' ); ?>
<div class="content-wrapper">
	<?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
		<header data-stellar-background-ratio="0.5" class="entry-header has-bg"
		        <?php if ( $wc_thememove_heading_image ){ ?>style="background-image: url('<?php echo esc_url($wc_thememove_heading_image); ?>')" <?php } ?>>
			<div class="container">
				<?php if ( get_post_meta( wc_get_page_id( 'shop' ), "thememove_alt_title", true ) ) { ?>
					<h1 class="entry-title">
						<?php echo get_post_meta( wc_get_page_id( 'shop' ), "thememove_alt_title", true ); ?>
					</h1>
				<?php } else { ?>
					<h1 class="entry-title">
						<?php woocommerce_page_title(); ?>
					</h1>
				<?php } ?>
				<?php
				if ($wc_thememove_bread_crumb_enable != 'disable') {
					if(function_exists('bcn_display')) {
						echo '<div class="breadcrumb"><div class="container">';
						bcn_display();
						echo '</div> </div>';
					} elseif( function_exists( 'tm_bread_crumb' ) ) {
						echo '<div class="breadcrumb"><div class="container">';
						echo tm_bread_crumb( array( 'home_label' => esc_html__( 'Home', 'structure' ) ) );
						echo '</div> </div>';
					}
				}
				?>
			</div>
		</header>
	<?php endif; ?>
	<div class="container">
		<div class="row">
			<?php if ( $layout == 'sidebar-content' || $layout == 2 ) { ?>
				<?php do_action( 'woocommerce_sidebar' ); ?>
			<?php } ?>
			<?php if ( $layout == 'sidebar-content' || $layout == 'content-sidebar' || $layout == 2 || $layout == 1 ) { ?>
				<?php $class = 'col-md-9'; ?>
			<?php } else { ?>
				<?php $class = 'col-md-12'; ?>
			<?php } ?>
			<div class="<?php echo esc_attr( $class ); ?>">
				<?php do_action( 'woocommerce_before_main_content' ); ?>

				<?php do_action( 'woocommerce_archive_description' ); ?>

				<?php
				if ( woocommerce_product_loop() ) {

					/**
					 * Hook: woocommerce_before_shop_loop.
					 *
					 * @hooked woocommerce_output_all_notices - 10
					 * @hooked woocommerce_result_count - 20
					 * @hooked woocommerce_catalog_ordering - 30
					 */
					do_action( 'woocommerce_before_shop_loop' );

					woocommerce_product_loop_start();

					if ( wc_get_loop_prop( 'total' ) ) {
						while ( have_posts() ) {
							the_post();

							/**
							 * Hook: woocommerce_shop_loop.
							 */
							do_action( 'woocommerce_shop_loop' );

							wc_get_template_part( 'content', 'product' );
						}
					}

					woocommerce_product_loop_end();

					/**
					 * Hook: woocommerce_after_shop_loop.
					 *
					 * @hooked woocommerce_pagination - 10
					 */
					do_action( 'woocommerce_after_shop_loop' );
				} else {
					/**
					 * Hook: woocommerce_no_products_found.
					 *
					 * @hooked wc_no_products_found - 10
					 */
					do_action( 'woocommerce_no_products_found' );
				}
				?>

				<?php do_action( 'woocommerce_after_main_content' ); ?>
			</div>
			<?php if ( $layout == 'content-sidebar' || $layout == 1 ) { ?>
				<?php do_action( 'woocommerce_sidebar' ); ?>
			<?php } ?>
		</div>
	</div>
</div>

<?php get_footer( 'shop' ); ?>
